@@ -2,7 +2,7 @@
 
 """
 NAME:
-    sparser.py  
+    sparser.py
 
 SYNOPSIS:
     sparser.py [options] filename
@@ -47,8 +47,6 @@ EXAMPLES:
 import sys
 import os
 import getopt
-import re
-import gzip
 
 from pyparsing import *
 
@@ -64,7 +62,7 @@ debug_p = 0
 
 
 #---positional args, default is empty---
-pargs = []    
+pargs = []
 
 
 #---other---
@@ -79,14 +77,14 @@ def msg(txt):
 def debug(ftn, txt):
     """Used for debugging."""
     if debug_p:
-        sys.stdout.write("{}.{}:{}\n".format(modname, ftn, txt))
+        sys.stdout.write("{0}.{1}:{2}\n".format(modname, ftn, txt))
         sys.stdout.flush()
 
 def fatal(ftn, txt):
     """If can't continue."""
-    msg = "{}.{}:FATAL:{}\n".format(modname, ftn, txt)
+    msg = "{0}.{1}:FATAL:{2}\n".format(modname, ftn, txt)
     raise SystemExit(msg)
- 
+
 def usage():
     """Prints the docstring."""
     print(__doc__)
@@ -118,7 +116,7 @@ class ParseFileLineByLine:
     compressed.  Compression is deduced from the file name suffixes '.Z'
     (compress/uncompress), '.gz' (gzip/gunzip), and '.bz2' (bzip2).
 
-    The parse definition file name is developed based on the input file name.
+    The parse definition fi le name is developed based on the input file name.
     If the input file name is 'basename.ext', then the definition file is
     'basename_def.ext'.  If a definition file specific to the input file is not
     found, then the program searches for the file 'sparse.def' which would be
@@ -129,10 +127,10 @@ class ParseFileLineByLine:
     or '~user' to indicate a home directory, as well as URLs (for reading
     only).
 
-    Constructor: 
+    Constructor:
     ParseFileLineByLine(|filename|, |mode|='"r"'), where |filename| is the name
     of the file (or a URL) and |mode| is one of '"r"' (read), '"w"' (write) or
-    '"a"' (append, not supported for .Z files).  
+    '"a"' (append, not supported for .Z files).
     """
 
     def __init__(self, filename, mode = 'r'):
@@ -154,27 +152,27 @@ class ParseFileLineByLine:
                     raise IOError(2, 'No such file or directory: ' + filename)
             filen, file_extension = os.path.splitext(filename)
             command_dict = {
-              ('.Z', 'r'): 
+              ('.Z', 'r'):
                 "self.file = os.popen('uncompress -c ' + filename, mode)",
-              ('.gz', 'r'): 
+              ('.gz', 'r'):
                 "self.file = gzip.GzipFile(filename, 'rb')",
-              ('.bz2', 'r'): 
+              ('.bz2', 'r'):
                 "self.file = os.popen('bzip2 -dc ' + filename, mode)",
-              ('.Z', 'w'): 
+              ('.Z', 'w'):
                 "self.file = os.popen('compress > ' + filename, mode)",
-              ('.gz', 'w'): 
+              ('.gz', 'w'):
                 "self.file = gzip.GzipFile(filename, 'wb')",
-              ('.bz2', 'w'): 
+              ('.bz2', 'w'):
                 "self.file = os.popen('bzip2 > ' + filename, mode)",
-              ('.Z', 'a'): 
+              ('.Z', 'a'):
                 "raise IOError, (0, 'Can\'t append to .Z files')",
-              ('.gz', 'a'): 
+              ('.gz', 'a'):
                 "self.file = gzip.GzipFile(filename, 'ab')",
-              ('.bz2', 'a'): 
+              ('.bz2', 'a'):
                 "raise IOError, (0, 'Can\'t append to .bz2 files')",
                            }
 
-            exec(command_dict.get((file_extension, mode), 
+            exec(command_dict.get((file_extension, mode),
                                   'self.file = open(filename, mode)'))
 
         self.grammar = None
@@ -211,54 +209,54 @@ class ParseFileLineByLine:
         decimal_sep = "."
         sign = oneOf("+ -")
         # part of printables without decimal_sep, +, -
-        special_chars = string.replace('!"#$%&\'()*,./:;<=>?@[\\]^_`{|}~', 
-                                       decimal_sep, "") 
+        special_chars = string.replace('!"#$%&\'()*,./:;<=>?@[\\]^_`{|}~',
+                                       decimal_sep, "")
         integer = ToInteger(
-                  Combine(Optional(sign) + 
+                  Combine(Optional(sign) +
                           Word(nums))).setName("integer")
         positive_integer = ToInteger(
-                           Combine(Optional("+") + 
+                           Combine(Optional("+") +
                                    Word(nums))).setName("integer")
         negative_integer = ToInteger(
-                           Combine("-" + 
+                           Combine("-" +
                                    Word(nums))).setName("integer")
         real = ToFloat(
-               Combine(Optional(sign) + 
-                       Word(nums) + 
-                       decimal_sep + 
-                       Optional(Word(nums)) + 
-                       Optional(oneOf("E e") + 
+               Combine(Optional(sign) +
+                       Word(nums) +
+                       decimal_sep +
+                       Optional(Word(nums)) +
+                       Optional(oneOf("E e") +
                                 Word(nums)))).setName("real")
         positive_real = ToFloat(
-                        Combine(Optional("+") + 
-                                Word(nums) + 
-                                decimal_sep + 
-                                Optional(Word(nums)) + 
-                                Optional(oneOf("E e") + 
+                        Combine(Optional("+") +
+                                Word(nums) +
+                                decimal_sep +
+                                Optional(Word(nums)) +
+                                Optional(oneOf("E e") +
                                          Word(nums)))).setName("real")
         negative_real = ToFloat(
-                        Combine("-" + 
-                                Word(nums) + 
-                                decimal_sep + 
-                                Optional(Word(nums)) + 
-                                Optional(oneOf("E e") + 
+                        Combine("-" +
+                                Word(nums) +
+                                decimal_sep +
+                                Optional(Word(nums)) +
+                                Optional(oneOf("E e") +
                                          Word(nums)))).setName("real")
         qString = ( sglQuotedString | dblQuotedString ).setName("qString")
-    
+
         # add other characters we should skip over between interesting fields
         integer_junk = Optional(
                        Suppress(
-                       Word(alphas + 
-                            special_chars + 
+                       Word(alphas +
+                            special_chars +
                             decimal_sep))).setName("integer_junk")
         real_junk = Optional(
                     Suppress(
-                    Word(alphas + 
+                    Word(alphas +
                          special_chars))).setName("real_junk")
         qString_junk = SkipTo(qString).setName("qString_junk")
 
         # Now that 'integer', 'real', and 'qString' have been assigned I can
-        # execute the definition file.  
+        # execute the definition file.
         exec(compile(open(self.parsedef).read(), self.parsedef, 'exec'))
 
         # Build the grammar, combination of the 'integer', 'real, 'qString',
@@ -337,7 +335,7 @@ def main(pargs):
     for i in fp:
         print(i)
 
-    
+
 #-------------------------
 if __name__ == '__main__':
     ftn = "main"
@@ -361,5 +359,5 @@ if __name__ == '__main__':
 
 #===Revision Log===
 #Created by mkpythonproj:
-#2006-02-06  Tim Cera  
+#2006-02-06  Tim Cera
 #
